<div align="center">

  <a href="https://github.com/offici5l/MiUnlockTool/releases/latest"><img src="https://img.shields.io/badge/MiUnlockTool-%23FF6900?style=flat&logo=xiaomi&logoColor=white" alt="MiUnlockTool" style="width: 200px; vertical-align: middle;" /> </a><br>

  <img src="https://img.shields.io/pypi/v/miunlock?label=Version&labelColor=black&color=brightgreen" alt="Version" /><br>
  <a href="CHANGELOG.md"><img src="https://img.shields.io/badge/Changelog-blue?style=flat&logoColor=white" alt="Changelog" /></a><br><p style="font-weight: bold;">Developed to retrieve <code>encryptData(token)</code>
  <br>
  for Xiaomi devices to unlock the bootloader.
  <br>
  Compatible with all platforms.</p>
  
 <h2>Windows, Linux, MacOS, Android(Termux)</h2>
 
  <a href="./LICENSE"><img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg" alt="Apache 2.0 License" /></a>
  <a href="https://t.me/Offici5l_Channel"><img src="https://img.shields.io/badge/Telegram-%230077B5?style=flat&logo=telegram&logoColor=white" alt="Telegram Channel" /></a>

</div>


## Requirements
- Python 3.7+

## Installation
```sh
pip install miunlock
```

## Usage
```sh
miunlock
```